==> aboutus-package-1.0.1.tgz: package/AboutUs.js <==
import React from 'react';
//import logo from './logo.svg';
import './App.css';
export function AboutUs() {
    return (React.createElement(React.Fragment, null,
        React.createElement("section", { className: "privacy" },
            React.createElement("div", { className: "container" },
                React.createElement("div", { className: "row" },
                    React.createElement("div", { className: "col-sm-12 text-center" },
                        React.createElement("h2", null, "ABOUT US"),
                        React.createElement("img", { src: "images/divider.png", width: "206", height: "26" }),
                        " "),
                    React.createElement("div", { className: "col-md-10 col-md-offset-1 text-center " },
                        React.createElement("p", null, "We sell quality canvases that are carefully selected  by art lovers who have an eye for unique and timeless art pieces."),
                        React.createElement("p", null, "We work with a trusted courier company that ensures safe and timely delivery of your art pieces ."))))),
        React.createElement("section", { className: "video" },
            React.createElement("div", { className: "col-lg-6 lesspad" },
                React.createElement("div", { className: "inn-video" },
                    React.createElement("img", { src: "images/about.jpg", className: "img-responsive" }))),
            React.createElement("div", { className: "col-lg-6" },
                React.createElement("div", { className: "why" },
                    React.createElement("h3", null, "WHAT WE ARE."),
                    React.createElement("ul", null,
                        React.createElement("li", null,
                            React.createElement("p", null, "Baobab Canvas\u2122 is an online store that specializes in the most authentic art pieces tailor-made for African art lovers that seek to be mesmerized by authentic African pieces. ")),
                        React.createElement("li", null,
                            React.createElement("p", null, "Let us dazzle you with authentic eye-catching canvases that speaks directly to your soul. ")),
                        React.createElement("li", null,
                            React.createElement("p", null, "Our choice selection of canvases is deeply rooted in the culture and traditions of our people, creativity blended with originality at it\u2019s very best!")),
                        React.createElement("li", null,
                            React.createElement("p", null, "With a touch of Grace, Beauty and Opulence, Welcome to the world of BAOBAB CANVAS\u2122."))))))));
}

==> aboutus-package-1.0.8.tgz: package/AboutUs.js <==
import React from 'react';
//import logo from './logo.svg';
import './App.css';
export function AboutUs() {
    return (React.createElement(React.Fragment, null,
        React.createElement("section", { className: "privacy" },
            React.createElement("div", { className: "container" },
                React.createElement("div", { className: "row" },
                    React.createElement("div", { className: "col-sm-12 text-center" },
                        React.createElement("h2", null, "ABOUT US"),
                        React.createElement("img", { src: "https://i.imgur.com/OF1Vh6t.png", width: "206", height: "26" }),
                        " "),
                    React.createElement("div", { className: "col-md-10 col-md-offset-1 text-center " },
                        React.createElement("p", null, "We sell quality canvases that are carefully selected  by art lovers who have an eye for unique and timeless art pieces."),
                        React.createElement("p", null, "We work with a trusted courier company that ensures safe and timely delivery of your art pieces ."))))),
        React.createElement("section", { className: "video" },
            React.createElement("div", { className: "col-lg-6 lesspad" },
                React.createElement("div", { className: "inn-video" },
                    React.createElement("img", { src: "https://i.imgur.com/MX8zL8A.jpg", className: "img-responsive" }))),
            React.createElement("div", { className: "col-lg-6" },
                React.createElement("div", { className: "why" },
                    React.createElement("h3", null, "WHAT WE ARE."),
                    React.createElement("ul", null,
                        React.createElement("li", null,
                            React.createElement("p", null, "Baobab Canvas\u2122 is an online store that specializes in the most authentic art pieces tailor-made for African art lovers that seek to be mesmerized by authentic African pieces. ")),
                        React.createElement("li", null,
                            React.createElement("p", null, "Let us dazzle you with authentic eye-catching canvases that speaks directly to your soul. ")),
                        React.createElement("li", null,
                            React.createElement("p", null, "Our choice selection of canvases is deeply rooted in the culture and traditions of our people, creativity blended with originality at it\u2019s very best!")),
                        React.createElement("li", null,
                            React.createElement("p", null, "With a touch of Grace, Beauty and Opulence, Welcome to the world of BAOBAB CANVAS\u2122."))))))));
}
